#!/usr/bin/env python
# encoding: utf-8
"""
Created by Brendan Erwin on 2008-05-21.
Copyright (c) 2008 Brendan Erwin. All rights reserved.

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

"""

import sys
import os
import serial
import time


class RepRapArduinoSerialSender:
	
	_verbose = False
	
	def __init__(self, verbose=False):
		self._verbose = verbose
		port = "/dev/ttyUSB0"

		if self._verbose:
			print >> sys.stdout, "Opening serial port: " + port
	
		#Timeout value 10" max travel, 1RPM, 20 threads/in = 200 seconds
		self.ser = serial.Serial(port, 19200, timeout=200)

		if self._verbose:
			print >> sys.stdout, "Serial Open?: " + str(self.ser.isOpen())
			print >> sys.stdout, "Baud Rate: " + str(self.ser.baudrate)

		#Reboot the arduino, and wait for it's response
		if self._verbose:
			print "reseting arduino..."

		self.ser.setDTR(0)
		time.sleep(1)
		self.ser.setDTR(1)
		print self.ser.readline()
		if self._verbose:
			print "Done with reset"

		pass

	def writeToArduino(self, dataToWrite):
		self.ser.write(dataToWrite)
		#The g-code firmware returns exactly ONE line per line of gcode sent.
		if self._verbose:
			print self.ser.readline().replace("\r",'').replace("\n",'')


	def close():
		if self._verbose:
			print >> sys.stdout, "Closing serial port."
		self.ser.close()

		if self._verbose:
			print >> sys.stdout, "Serial Open?: " + str(self.ser.isOpen())
