#!/usr/bin/env python
# encoding: utf-8
"""
Created by Brendan Erwin on 2008-05-21.
Modified by John Gilmore 2008-08-23
Copyright (c) 2008 Brendan Erwin. All rights reserved.
Copyright (c) 2008 John Gilmore.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""

import sys
import getopt
import RepRapArduinoSerialSender

help_message = '''
Usage:	send <filename> [-v]
	send <single g-code statement> -v
	-v : Verbose

You may call this with either a single statement of g-code
to be sent to the arduino, or with the name of a g-code file.

------------------------------------------------------------------

Copyright (C) 2008 Brendan Erwin
Copyright (C) 2008 John Gilmore

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
'''
#This was originally release by Brendan under GPLv2 or later


class Usage(Exception):
	def __init__(self, msg):
		self.msg = msg

def main(argv=None):

	verbose = False

	if argv is None:
		argv = sys.argv
		
	try:
		try:
			opts, args = getopt.getopt(argv[2:], "ho:v", ["help", "output="])
		except getopt.error, msg:
			raise Usage(msg)
	
		# option processing
		for option, value in opts:
			if option == "-v":
				verbose = True
				print "verbosity set to True"
			if option in ("-h", "--help"):
				raise Usage(help_message)
	
	except Usage, err:
		#print >> sys.stderr, sys.argv[0].split("/")[-1] + ": " + str(err.msg)
		print >> sys.stderr, str(err.msg)
		print >> sys.stderr, "For help use --help"
		return 2
	
	try:
		datafile = open(sys.argv[1])
	except:
		#Ignore verbose settings here, as if it's a typo we'll want to know.
		print "Unable to open file, assuming it's one line of direct G-code..."
		print sys.argv[1]
		sender = RepRapArduinoSerialSender.RepRapArduinoSerialSender(verbose)
		sender.writeToArduino(sys.argv[1])
		return 0

	sender = RepRapArduinoSerialSender.RepRapArduinoSerialSender(verbose)
	try:
		for line in datafile:
			if verbose:
				print line.replace("\r",'').replace("\n",'')
			# Ignore lines with comments (not technically correct, should ignore only the comment,
			# but all gcode files that I've actually seen so far don't have code on comment lines.
			if '(' in line or '"' in line:
				continue
			# The arduino GCode interperter firmware doesn't like whitespace
			line=line.replace(' ','')
			line=line.replace("\t",'')
			line=line.replace("\r",'')
			line=line.replace("\n",'')
			#Skip blank lines.
			if len(line) == 0:
				continue
			sender.writeToArduino(line)
	finally:
		datafile.close()
	
	return 0

if __name__ == "__main__":
	sys.exit(main())
